@@ -2,6 +2,7 @@
 from _globals import PATHDIR
 from emora_stdm import DialogueFlow, Macro
 import random
+from emora._flows._central_knowledge import central_knowledge
 
 animal_movie = {
     "a street cat named bob": "it is a feel-good story of how James Bowen, a recovering drug addict, had his life transformed when he met a stray ginger cat",
@@ -85,10 +86,7 @@ class JokeAnswer(Macro):
         return animal_jokes[vars['animal_joke']]
 
 animals = DialogueFlow('_local_start', macros={'MOVIE':Movie(),'MOVIEFACT':MovieFact(),'CHECKMOVIE':CheckKnowsMovie(),
-                                               'JOKE':Joke(),'JOKEANSWER':JokeAnswer()})
-
-animals.knowledge_base().load_json_file(PATHDIR.replace('__***__', '_common.json'))
-animals.knowledge_base().load_json_file(PATHDIR.replace('__***__', 'animals.json'))
+                                               'JOKE':Joke(),'JOKEANSWER':JokeAnswer()}, kb=central_knowledge)
 
 animals.add_system_transition('_local_start', 'start', '')
 
@@ -989,7 +987,7 @@ want_pet = {
                     'state': 'likes_other',
                     'score': 0.9,
 
-                    '`Oh, you don\'t want either a cat or a dog? An ` $wants_pet ` would be a cool pet '
+                    '`Oh, you don\'t want either a cat or a dog? A ` $wants_pet ` would be a cool pet '
                     'for sure! I hope you can get one soon! `':
                         'exit'
                 },
