@@ -1081,4 +1081,6 @@ class DialogueFlow:
         self.reset()
         self.set_state(config['state'])
         self.set_vars(config['vars'])
-        self.set_gates(defaultdict(config['gates']))
+        gates = defaultdict(list)
+        gates.update(config['gates'])
+        self.set_gates(gates)
